"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        log('Initializing highlighter with:', {
          langs: initialLanguages.map(l => l.name),
          themes: initialThemes.map(t => t.name)
        });
        const highlighter = await createHighlighterCore({
          // Pass langs and themes directly
          langs: initialLanguages,
          themes: initialThemes,
          // Use JavaScript regex engine which is more portable
          engine: createJavaScriptRegexEngine({
            forgiving: true,
            cache: new Map()
          })
        });
        setHighlighter(highlighter);
        setIsReady(true);
        log('Highlighter ready with:', {
          languages: highlighter.getLoadedLanguages(),
          themes: highlighter.getLoadedThemes()
        });
      } catch (err) {
        console.error('Failed to initialize highlighter:', err);
        setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
      }
    };
    initHighlighter();
  }, []); // Empty deps since inputs should be stable

  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map